package javax.swing;

import java.io.Serializable;

public class SizeRequirements implements Serializable
{
    public int minimum;
    public int preferred;
    public int maximum;
    public float alignment;
    
    public SizeRequirements() {
        this.minimum = 0;
        this.preferred = 0;
        this.maximum = 0;
        this.alignment = 0.5f;
    }
    
    public SizeRequirements(int minimum, int preferred, int maximum, float n) {
        this.minimum = minimum;
        this.preferred = preferred;
        this.maximum = maximum;
        this.alignment = ((n > 1.0f) ? 1.0f : ((n < 0.0f) ? 0.0f : n));
    }
    
    @Override
    public String toString() {
        return "[" + this.minimum + "," + this.preferred + "," + this.maximum + "]@" + this.alignment;
    }
    
    public static SizeRequirements getTiledSizeRequirements(SizeRequirements[] array) {
        SizeRequirements sizeRequirements = new SizeRequirements();
        for (int i = 0; i < array.length; ++i) {
            SizeRequirements sizeRequirements2 = array[i];
            sizeRequirements.minimum = (int)Math.min((long)sizeRequirements.minimum + (long)sizeRequirements2.minimum, 2147483647L);
            sizeRequirements.preferred = (int)Math.min((long)sizeRequirements.preferred + (long)sizeRequirements2.preferred, 2147483647L);
            sizeRequirements.maximum = (int)Math.min((long)sizeRequirements.maximum + (long)sizeRequirements2.maximum, 2147483647L);
        }
        return sizeRequirements;
    }
    
    public static SizeRequirements getAlignedSizeRequirements(SizeRequirements[] array) {
        SizeRequirements sizeRequirements = new SizeRequirements();
        SizeRequirements sizeRequirements2 = new SizeRequirements();
        for (int i = 0; i < array.length; ++i) {
            SizeRequirements sizeRequirements3 = array[i];
            int a = (int)(sizeRequirements3.alignment * (float)sizeRequirements3.minimum);
            int a2 = sizeRequirements3.minimum - a;
            sizeRequirements.minimum = Math.max(a, sizeRequirements.minimum);
            sizeRequirements2.minimum = Math.max(a2, sizeRequirements2.minimum);
            int a3 = (int)(sizeRequirements3.alignment * (float)sizeRequirements3.preferred);
            int a4 = sizeRequirements3.preferred - a3;
            sizeRequirements.preferred = Math.max(a3, sizeRequirements.preferred);
            sizeRequirements2.preferred = Math.max(a4, sizeRequirements2.preferred);
            int a5 = (int)(sizeRequirements3.alignment * (float)sizeRequirements3.maximum);
            int a6 = sizeRequirements3.maximum - a5;
            sizeRequirements.maximum = Math.max(a5, sizeRequirements.maximum);
            sizeRequirements2.maximum = Math.max(a6, sizeRequirements2.maximum);
        }
        int n = (int)Math.min((long)sizeRequirements.minimum + (long)sizeRequirements2.minimum, 2147483647L);
        int n2 = (int)Math.min((long)sizeRequirements.preferred + (long)sizeRequirements2.preferred, 2147483647L);
        int n3 = (int)Math.min((long)sizeRequirements.maximum + (long)sizeRequirements2.maximum, 2147483647L);
        float n4 = 0.0f;
        if (n > 0) {
            float n5 = (float)sizeRequirements.minimum / (float)n;
            n4 = ((n5 > 1.0f) ? 1.0f : ((n5 < 0.0f) ? 0.0f : n5));
        }
        return new SizeRequirements(n, n2, n3, n4);
    }
    
    public static void calculateTiledPositions(int n, SizeRequirements sizeRequirements, SizeRequirements[] array, int[] array2, int[] array3) {
        calculateTiledPositions(n, sizeRequirements, array, array2, array3, true);
    }
    
    public static void calculateTiledPositions(int n, SizeRequirements sizeRequirements, SizeRequirements[] array, int[] array2, int[] array3, boolean b) {
        long n2 = 0L;
        long n3 = 0L;
        long n4 = 0L;
        for (int i = 0; i < array.length; ++i) {
            n2 += (long)array[i].minimum;
            n3 += (long)array[i].preferred;
            n4 += (long)array[i].maximum;
        }
        if ((long)n >= n3) {
            expandedTile(n, n2, n3, n4, array, array2, array3, b);
        }
        else {
            compressedTile(n, n2, n3, n4, array, array2, array3, b);
        }
    }
    
    private static void compressedTile(int n, long n2, long n3, long n4, SizeRequirements[] array, int[] array2, int[] array3, boolean b) {
        float n5 = (float)Math.min(n3 - (long)n, n3 - n2);
        float n6 = (n3 - n2 == 0L) ? 0.0f : (n5 / (float)(n3 - n2));
        if (b) {
            int n7 = 0;
            for (int j = 0; j < array3.length; ++j) {
                array2[j] = n7;
                SizeRequirements sizeRequirements2 = array[j];
                array3[j] = (int)((float)sizeRequirements2.preferred - n6 * (float)(sizeRequirements2.preferred - sizeRequirements2.minimum));
                n7 = (int)Math.min((long)n7 + (long)array3[j], 2147483647L);
            }
        }
        else {
            for (int i = 0; i < array3.length; ++i) {
                SizeRequirements sizeRequirements = array[i];
                array3[i] = (int)((float)sizeRequirements.preferred - n6 * (float)(sizeRequirements.preferred - sizeRequirements.minimum));
                array2[i] = n - array3[i];
                n = (int)Math.max((long)n - (long)array3[i], 0L);
            }
        }
    }
    
    private static void expandedTile(int n, long n2, long n3, long n4, SizeRequirements[] array, int[] array2, int[] array3, boolean b) {
        float n5 = (float)Math.min((long)n - n3, n4 - n3);
        float n6 = (n4 - n3 == 0L) ? 0.0f : (n5 / (float)(n4 - n3));
        if (b) {
            int n7 = 0;
            for (int j = 0; j < array3.length; ++j) {
                array2[j] = n7;
                SizeRequirements sizeRequirements2 = array[j];
                array3[j] = (int)Math.min((long)sizeRequirements2.preferred + (long)(int)(n6 * (float)(sizeRequirements2.maximum - sizeRequirements2.preferred)), 2147483647L);
                n7 = (int)Math.min((long)n7 + (long)array3[j], 2147483647L);
            }
        }
        else {
            for (int i = 0; i < array3.length; ++i) {
                SizeRequirements sizeRequirements = array[i];
                array3[i] = (int)Math.min((long)sizeRequirements.preferred + (long)(int)(n6 * (float)(sizeRequirements.maximum - sizeRequirements.preferred)), 2147483647L);
                array2[i] = n - array3[i];
                n = (int)Math.max((long)n - (long)array3[i], 0L);
            }
        }
    }
    
    public static void calculateAlignedPositions(int n, SizeRequirements sizeRequirements, SizeRequirements[] array, int[] array2, int[] array3) {
        calculateAlignedPositions(n, sizeRequirements, array, array2, array3, true);
    }
    
    public static void calculateAlignedPositions(int n, SizeRequirements sizeRequirements, SizeRequirements[] array, int[] array2, int[] array3, boolean b) {
        int a = (int)((float)n * (b ? sizeRequirements.alignment : (1.0f - sizeRequirements.alignment)));
        int a2 = n - a;
        for (int i = 0; i < array.length; ++i) {
            SizeRequirements sizeRequirements2 = array[i];
            int b2 = (int)((float)sizeRequirements2.maximum * (b ? sizeRequirements2.alignment : (1.0f - sizeRequirements2.alignment)));
            int b3 = sizeRequirements2.maximum - b2;
            int min = Math.min(a, b2);
            int min2 = Math.min(a2, b3);
            array2[i] = a - min;
            array3[i] = (int)Math.min((long)min + (long)min2, 2147483647L);
        }
    }
    
    public static int[] adjustSizes(int n, SizeRequirements[] array) {
        return new int[0];
    }
}
